[svn] gcry - r1260 - in trunk: . cipher

svn author wk cvs at cvs.gnupg.org
Wed Aug 22 11:11:37 CEST 2007


Author: wk
Date: 2007-08-22 11:11:06 +0200 (Wed, 22 Aug 2007)
New Revision: 1260

Modified:
   trunk/ChangeLog
   trunk/README
   trunk/cipher/ChangeLog
   trunk/cipher/md.c
   trunk/cipher/rndw32.c
   trunk/configure.ac
Log:
Changed rndw32 to LGPL.
Typo fixes.


Modified: trunk/ChangeLog
===================================================================
--- trunk/ChangeLog	2007-07-26 09:15:12 UTC (rev 1259)
+++ trunk/ChangeLog	2007-08-22 09:11:06 UTC (rev 1260)
@@ -1,3 +1,11 @@
+2007-08-22  Werner Koch  <wk at g10code.com>
+
+	* configure.ac (USE_RNDW32): Unmark rndw32 as GPL.
+
+2007-08-08  Werner Koch  <wk at g10code.com>
+
+	* configure.ac: Use $host and not $target.
+
 2007-07-26  Werner Koch  <wk at g10code.com>
 
 	* acinclude.m4 (GNUPG_SYS_SYMBOL_UNDERSCORE): Fix a syntax error

Modified: trunk/README
===================================================================
--- trunk/README	2007-07-26 09:15:12 UTC (rev 1259)
+++ trunk/README	2007-08-22 09:11:06 UTC (rev 1260)
@@ -53,7 +53,6 @@
     are:
 
       rndunix   - Entropy gatherer for Unices without a /dev/random
-      rndw32    - Entropy gatherer for MS Windows
       gcryptrnd - The random number daemon.
       getrandom - A client for that daemon.
 

Modified: trunk/cipher/ChangeLog
===================================================================
--- trunk/cipher/ChangeLog	2007-07-26 09:15:12 UTC (rev 1259)
+++ trunk/cipher/ChangeLog	2007-08-22 09:11:06 UTC (rev 1260)
@@ -1,3 +1,7 @@
+2007-08-22  Werner Koch  <wk at g10code.com>
+
+	* rndw32.c: Switched tpo LGPL.
+
 2007-05-30  Werner Koch  <wk at g10code.com>
 
 	* camellia.h, camellia.c: Replace by new LGPL version and adjusted

Modified: trunk/cipher/md.c
===================================================================
--- trunk/cipher/md.c	2007-07-26 09:15:12 UTC (rev 1259)
+++ trunk/cipher/md.c	2007-08-22 09:11:06 UTC (rev 1260)
@@ -885,7 +885,7 @@
     {
       /* return the first algorithm */
       if (r && r->next)
-	log_debug("more than algorithm in md_read(0)\n");
+	log_debug ("more than one algorithm in md_read(0)\n");
       return r->digest->read( &r->context.c );
     }
   else
@@ -1133,7 +1133,7 @@
 	    memcpy (buffer, asn, asnlen);
 	    *nbytes = asnlen;
 	  }
-          else if ((! buffer) && nbytes)
+          else if (!buffer && nbytes)
             *nbytes = asnlen;
           else
             {
@@ -1200,7 +1200,7 @@
  *	Returns 1 when the handle works on secured memory
  *	otherwise 0 is returned.  There is no error return.
  *  GCRYCTL_IS_ALGO_ENABLED:
- *     Returns 1 if the algo is enanled for that handle.
+ *     Returns 1 if the algo is enabled for that handle.
  *     The algo must be passed as the address of an int.
  */
 gcry_error_t

Modified: trunk/cipher/rndw32.c
===================================================================
--- trunk/configure.ac	2007-07-26 09:15:12 UTC (rev 1259)
+++ trunk/configure.ac	2007-08-22 09:11:06 UTC (rev 1260)
@@ -53,9 +53,9 @@
 VERSION=$PACKAGE_VERSION
 
 AC_CONFIG_SRCDIR([src/libgcrypt.vers])
-AC_CANONICAL_TARGET()
 AM_INIT_AUTOMAKE($PACKAGE, $VERSION)
 AM_CONFIG_HEADER(config.h)
+AC_CANONICAL_HOST
 AM_MAINTAINER_MODE
 
 AH_TOP([
@@ -156,8 +156,8 @@
 print_egd_notice=no
 have_w32_system=no
 
-# Setup some stuff depending on host/target.
-case "${target}" in
+# Setup some stuff depending on host.
+case "${host}" in
     *-*-mingw32*)
       available_random_modules="w32"
       ac_cv_have_dev_random=no
@@ -218,7 +218,7 @@
 
 
 # A printable OS Name is sometimes useful.
-case "${target}" in
+case "${host}" in
     *-*-mingw32*)
         PRINTABLE_OS_NAME="MingW32"
         ;;
@@ -241,7 +241,7 @@
 esac
 
 # Figure out the name of the random device
-case "${target}" in
+case "${host}" in
     *-openbsd*)
         # FIXME: Are these the best flags for OpenBSD?
         NAME_OF_DEV_RANDOM="/dev/srandom"
@@ -641,7 +641,7 @@
         # Try Linuxish random device.
         random_modules="linux"
     else
-        case "${target}" in
+        case "${host}" in
         *-*-mingw32*|*-*-cygwin*)
           # Windows random device.
           random_modules="w32"
@@ -920,8 +920,7 @@
                   [Defined if the EGD based RNG should be used.])
 
 LIST_MEMBER(w32, $random_modules)
-test "$found" = "1" && GCRYPT_RANDOM="$GCRYPT_RANDOM rndw32.lo" \
-                    && gpl="$gpl rndw32"
+test "$found" = "1" && GCRYPT_RANDOM="$GCRYPT_RANDOM rndw32.lo"
 AC_DEFINE_UNQUOTED(USE_RNDW32, $found,
                   [Defined if the Windows specific RNG should be used.])
 
@@ -1010,5 +1009,5 @@
 fi
 
 # Give some feedback
-echo   "                Configured for: $PRINTABLE_OS_NAME ($target)"
+echo   "                Configured for: $PRINTABLE_OS_NAME ($host)"
 echo




More information about the Gnupg-commits mailing list
--- trunk/cipher/rndw32.c	2007-07-26 09:15:12 UTC (rev 1259)
+++ trunk/cipher/rndw32.c	2007-08-22 09:11:06 UTC (rev 1260)
@@ -34,15 +34,38 @@
  *    author, <pgut001 at cs.auckland.ac.nz> to allow them to be added to the
  *    baseline version of the code.
  *
  * ALTERNATIVELY, the code may be distributed under the terms of the GNU
  * General Public License, version 2 or any later version published by the
  * Free Software Foundation, in which case the provisions of the GNU GPL are
  * required INSTEAD OF the above restrictions.
  *
  * Although not required under the terms of the GPL, it would still be nice if
  * you could make any changes available to the author to allow a consistent
  * code base to be maintained
  *************************************************************************
+ * The above alternative was changed from GPL to LGPL on 2007-08-22 with
+ * permission from Peter Gutmann:
+ *==========
+ From: pgut001 <pgut001 at cs.auckland.ac.nz>
+ Subject: Re: LGPL for the windows entropy gatherer
+ To: wk at gnupg.org
+ Date: Wed, 22 Aug 2007 03:05:42 +1200
+ 
+ Hi,
+ 
+ >As of now libgcrypt is GPL under Windows due to that module and some people
+ >would really like to see it under LGPL too.  Can you do such a license change
+ >to LGPL version 2?  Note that LGPL give the user the option to relicense it
+ >under GPL, so the change would be pretty easy and backwar compatible.
+ 
+ Sure.  I assumed that since GPG was GPLd, you'd prefer the GPL for the entropy
+ code as well, but Ian asked for LGPL as an option so as of the next release
+ I'll have LGPL in there.  You can consider it to be retroactive, so your
+ current version will be LGPLd as well.
+ 
+ Peter.
+ *==========
  */
 
 #include <config.h>
@@ -481,7 +504,8 @@
 		pPerfData = gcry_realloc (pPerfData, cbPerfData);
 	    }
 	    else {
-		log_debug ( "rndw32: get performance data problem\n");
+		log_debug ("rndw32: get performance data problem: ec=%ld\n", 
+                           status);
 		break;
 	    }
 	}
@@ -34,15 +34,38 @@
  *    baseline version of the code.
  *
- * ALTERNATIVELY, the code may be distributed under the terms of the GNU
- * General Public License, version 2 or any later version published by the
- * Free Software Foundation, in which case the provisions of the GNU GPL are
- * required INSTEAD OF the above restrictions.
+ * ALTERNATIVELY, the code may be distributed under the terms of the
+ * GNU Lesser General Public License, version 2.1 or any later version
+ * published by the Free Software Foundation, in which case the
+ * provisions of the GNU LGPL are required INSTEAD OF the above
+ * restrictions.
  *
@@ -34,15 +34,38 @@
  *
- * Although not required under the terms of the GPL, it would still be nice if
- * you could make any changes available to the author to allow a consistent
- * code base to be maintained
+ * Although not required under the terms of the LGPL, it would still
+ * be nice if you could make any changes available to the author to
+ * allow a consistent code base to be maintained.
  *************************************************************************

Modified: trunk/configure.ac
===================================================================